bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 15. Aventiure
___________________________________________________
| ### An dem vierdem morgen zwen vnt drizech man ### sach man ce hove riten daz wart do chvnt getan [331a] ### Gvnther dem vil richen im wære widerseit ### von lvge erwohsen vrovn Criemhilde div aller grozzesten leit ### Vrlovp si namen daz si fvr solden gan ### vnd iahen daz siz wæren Livdegeres man ### den ê hete betwngen div Sifrides hant ### vnd in ce gisel brahte in daz Gvntheres lant
###### 876 | ### Di boten er do grvzte vnd hiez si sitzen gan ### ir einer sprach dar vnder herre lat vns stan ### vnze wir sagen mære die iv enbotten sint ### ia habt ir ce <vinde> daz wizzet maniger mvter chint
| ### Iv widersaget Livdegast vnd Livdeger ### den ir da wilen tatet div grozlichen ser ### di wellent zv ziv riten mit her in diz lant ### der chvenich begonde zvrnen do er div mære bevant
###### 878 | ### Do hiez man di meinræten zen herbergen varn ### wi mohte sich her Sifrit do da vor bewarn ### er oder andr iemen daz si da trvgen an ### daz wart sit in selben ce grozem leide getan
###### 879 | ### Der chvnich mit sinen vrivnden rvonende gie ### Hagen von Tronege in nie gerwen lie ### noch heten ez gescheiden genvge skveniges man ### done wolt et Hagene nie des tages ab gegan
| ### Eines tages si Sifriden rwoende vant ### do begonde vragen der helt von Niderlant ### wi gat so trvrechliche der chvnich vnt sine man ### daz hilf ich im imer rechen hat im iemen iht getan
###### 881 | ### Do sprach der herre Gvnther mir ist von schvlden leit ### Livdegast vnd Livdeter di habent mir widerseit ### si wellent offenlichen riten in min lant ### do sprach der degen chvne daz sol div Sifrides hant
###### 882 | ### nach allen iwern eren mit vlize vnderstan ### ich getvn noch den dægenen als ich han ê getan ### ich gelege in wehste ir bverge vnd ovch ir lant ### ê daz ich erwinde des sin min hovbet iwer pfant
| ### Ir vnt iwer recken svlt hi heime bestan ### vnd lat mich zv <zin> riten mit den di ich han ### daz ich iv gerne diene daz laz ich ivch sehen ### von mir sol eweren vienden daz wizzet leide geschehen
###### 884 | ### So wol mich dirre mære sprach der chvenich do ### als ob er ernstliche der helffe wære vro ### mit valsche neig im tieffe der vngetriwe man ### do sprach der herre Sifrit ir svlt vil chleine sorge han [331b]
###### 885 | ### Do schichten si di reise mit den chnehten dan ### Sifride vnd den sinen ce sehen was ez getan ### do hiez er sich bereiten di von Niderlant ### di Sifrides recken svchten stritechlich gewant
| ### Do sprach der starche Sifrit min vater Sigemvnt ### ir svlt hi beliben wir chomen in chvrcer stvnt ### git vns got gelveche her wider an den Rin ### ir svlt bi dem chvnige hie vil vroliche sin
###### 887 | ### Div zeichen si an bvnden also si wolden dan ### da waren genvge di Gvntheres man ### dine wessen niht der mære <da> von ez was geschehen ### man mohte groz gesinde do bi Sifride sehen
###### 888 | ### Ir helme vnd ovch ir prvenne si bvnden vf di march ### sich bereite vome lande vil manich ritter starch ### so gi von Tronege Hagene da er Criemhilde vant ### vnt bat im geben vrlovp si wolden rvmen daz lant
| ### Nv wol mich sprach do Criemhilt daz ich ie gewan den man ### der minen lieben vrivnden wol tar vor gestan ### also min herre Sifrit tvt den vrivnden min ### des wil ich hohes mvtes sprach div chveneginne sin
###### 890 | ### Vil lieber vrivnt Hagene gedenchet ane daz ### daz ich iv gerne diene vnd noch nie wart gehaz ### des lazzet mich geniezen an minem liebem man ### ern sol des niht engelten hab ich Prvnnhilde iht getan
###### 891 | ### Daz hat mich sit gerwoen sprach daz edel wip ### ovch hat er dar vmbe cerblwoen minen lip ### daz ich iz ie geredete daz beswæret ir den mvt ### daz hat vil wol errochen der helt chvne vnd gvt
| ### Er sprach ir wert versvenet noch wol nach disen tagen ### Criemhilt min liebiv vrowe ia svlt ir mir sagen ### wi ich iv mvge gedienen an Sifride iwerm man ### daz tvn ich gerne vrowe wand iches niemen baz engan
###### 893 | ### Ich wære an alle sorge sprach daz edel wip ### daz im iemen næme in stvrme sinen lip ### ob er niht wolde volgen siner vebermvt ### so wære im sicher der degen chvne vnd gvt
###### 894 | ### Vrowe sprach do Hagene vnt habt ir des wan ### daz man in mvege [332a] versniden ir svlt mich wizzen lan ### mit wi getanen listen ich daz sol vndersten ### ich wil <im> ce hvte immer riten vnd gen
| ### Si sprach dv bist min mach vnd ich pin <der> din ### ich bevilhe dir mit triwen den lieben wine min ### daz tv mir wol behvetest den min holden man
###### 896 | ### Si sprach min man ist chvene vnt dar zv starch genvch ### do er den lintrachen an dem berge slvch ### ia badete sich in dem plvote der reche vil gemeit ### da von in sit in stvrmen nie dehein waffen versneit
###### 897 | ### Iedoch pin ich in sorgen swenn er in strite stat ### vnd vil der gershvezze von helden hande gat ### daz ich da verliese den minen lieben man ### hey waz ich grozzer sorge <diche> vmbe Sifriden han
| ### Ich meld iz vf genade vil lieber <vrivnt> ### daz dv dine triwe behaltest ane mir ### da man da mach verhowen den minen lieben man ### daz laz ich dich hoeren deist vf genade getan
###### 899 | ### Do von des trachen wnden volz daz heize blvt ### vnd sich dar inne badete der chvene ritter gvt ### do viel im zwihssen di herte ein lindenblat vil breit ### da mach man in versniden des ist mir sorgen vil bereit
###### 900 | ### Do sprach von Tronege Hagene vf daz sin gewant ### næt ir im ein chleinez ceichen da ist mir bi bechant ### wa ich in mvege behevten so wir in stvrme stan ### si wanden helt do vristen ez was vf sinen tot getan
| ### Si sprach mit chleinen siden næ ich vf sin gewant ### ein tovgenlichez crvece da sol helt din hant ### den minen man behivten so ez an di herte gat ### swenn er in den stvermen vor sinen vienden stat
###### 902 | ### Daz tvn ich sprach do Hagene vil liebiv vrowe min ### do wand ovch des div vrowe ez sol im vrvme sin ### do was da mit verraten der Criemhilde man ### vrlovp nam do Hagene do gie er vroeliche dan
###### 903 | ### Des chveneges ingesinde was alliz samt gemvt ### ich wæne immer recke mer deheiner tvt ### so grozer meinræte so da von im ergie ### do sich an sine triwe Criemhilt div chveneginne lie
| ### Des andern morgens mit tvsent siner [332b] man ### reit der herre Sifrit vil vroelichen dan ### er wand er solde rechen der siner vrivnde leit ### Hagen im reit so nahen daz er geschowete div chleit
###### 905 | ### Als er gesach daz pilde do schiet er tovgen dan ### di sageten ander mære zwene siner man ### mit vride solde beliben daz Gvntheres lant ### vnd si hete Livdger zv dem chvenige gesant
###### 906 | ### Wi vngerne Sifrit do hin wider reit ### ern het etewaz errochen siner vrivnde leit ### wand in vil chvm erwanden di Gvntheres man ### do reit er zv dem kvenige der wirt im danchen began
| ### Nv lon iv got des willen vrivnt Sifrit ### daz ir so willechliche tvt des ich ivch bit ### daz sol ich immer dienen als ich von rehte sol ### vor allen minen vrivnden so getrwe ich iv wol
###### 908 | ### Nv wir der herverte ledich worden sin ### so wil ich iagen riten bern vnd swin ### hin cem Waschemwalde als ich vil dike han getan ### daz het geraten Hagene der vil vngetriwe man
###### 909 | ### Allen minen gesten sol man daz sagen ### daz wir vil vrv riten di wellen mit mir iagen ### daz si sich bereiten di aber hie bestan ### hovhssen mit den vrowen daz si mir liebe getan
| ### Do sprach der herre Sifrit mit herlichem site ### swenne ir iagen ritet da wil ich gerne mite ### so svlt ir mir lihen einen svcheman ### vnd etelichen bracken so wil ich riten in den tan
###### 911 | ### Welt ir niht nemen einen sprach der kvenich cehant ### ich lih iv welt ir viere den vil wol ist bechant ### der walt vnde ovch <di> stige da div tier hine gant ### die ivch niht fverwise cen herbergen riten lant
###### 912 | ### Do reit zv sinem wibe der recke vil gemeit ### schiere hete Hagene dem kvenige geseit ### wir gewinnen wol den tiwerlichen degen ### svs getaner vntriwe solde niemer man gepflegen

<<< Übersicht <<< vorige Seite nächste Seite >>>